@@ -18,9 +18,9 @@ class Connector:
         self.logger = get_logger('connectors')
         try:
             if config_from_local:
-                self.client = self._get_client_from_local(mount_path)
+                self.client = self._get_client_from_local(secret_file)
             else:
-                self.client = self._get_client_from_oc(secret_file)
+                self.client = self._get_client_from_oc(mount_path)
         except Exception as e:
             self.logger.error(f"Failed to initialize client, {e}")
             self.client = None
